%define anolis_release 1
%global toolchain clang

# Opt out of https://fedoraproject.org/wiki/Changes/fno-omit-frame-pointer
# https://bugzilla.redhat.com/show_bug.cgi?id=2158587
%undefine _include_frame_pointers

%bcond_without check

#global rc_ver 3
%global lld_srcdir lld-%{maj_ver}.%{min_ver}.%{patch_ver}%{?rc_ver:rc%{rc_ver}}.src
%global maj_ver 15
%global min_ver 0
%global patch_ver 7

Name:		lld
Version:	%{maj_ver}.%{min_ver}.%{patch_ver}
Release:	%{anolis_release}%{?dist}
Summary:	The LLVM Linker

License:	Apache-2.0 WITH LLVM-exception OR NCSA
URL:		http://llvm.org
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{maj_ver}.%{min_ver}.%{patch_ver}/%{lld_srcdir}.tar.xz

Patch0:		0001-PATCH-lld-CMake-Check-for-gtest-headers-even-if-lit..patch

# Bundle libunwind header need during build for MachO support
Patch1:		0002-PATCH-lld-Import-compact_unwind_encoding.h-from-libu.patch

BuildRequires:	clang
BuildRequires:	cmake
BuildRequires:	ninja-build
BuildRequires:	llvm-devel = %{version}
BuildRequires:	llvm-test = %{version}
BuildRequires:	llvm-googletest = %{version}
BuildRequires:	ncurses-devel
BuildRequires:	zlib-devel

# For make check:
BuildRequires:	python3-rpm-macros
BuildRequires:	python3-lit

Requires(post): %{_sbindir}/update-alternatives
Requires(preun): %{_sbindir}/update-alternatives

Requires: %{name}-libs = %{version}-%{release}

%description
The LLVM project linker.

%package devel
Summary:	Libraries and header files for LLD
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name} = %{version}-%{release}

%description devel
This package contains library and header files needed to develop new native
programs that use the LLD infrastructure.

%package libs
Summary:	LLD shared libraries

%description libs
Shared libraries for LLD.

%package doc
Summary:        Documentation for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentations for %{name}

%prep
%autosetup -n %{lld_srcdir} -p2

%build

%cmake \
	-GNinja \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_INSTALL_PREFIX=%{_prefix} \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_DYLIB_COMPONENTS="all" \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DPYTHON_EXECUTABLE=%{__python3} \
	-DLLVM_INCLUDE_TESTS=ON \
	-DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
	-DLLVM_LIT_ARGS="-sv \
	--path %{_libdir}/llvm" \
	-DLLVM_LIBDIR_SUFFIX=64 \
	-DLLVM_MAIN_SRC_DIR=%{_datadir}/llvm/src

%cmake_build

%install

# Install libraries and binaries
%cmake_install

# This is generated by Patch1 during build and (probably) must be removed afterward
rm %{buildroot}%{_includedir}/mach-o/compact_unwind_encoding.h

# Required when using update-alternatives:
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Alternatives/
touch %{buildroot}%{_bindir}/ld

%post
%{_sbindir}/update-alternatives --install %{_bindir}/ld ld %{_bindir}/ld.lld 1

%postun
if [ $1 -eq 0 ] ; then
  %{_sbindir}/update-alternatives --remove ld %{_bindir}/ld.lld
fi

%check

%if %{with check}
%cmake_build --target check-lld
%endif

%files
%license LICENSE.TXT
%ghost %{_bindir}/ld
%{_bindir}/lld*
%{_bindir}/ld.lld
%{_bindir}/ld64.lld
%{_bindir}/wasm-ld

%files devel
%{_includedir}/lld
%{_libdir}/liblld*.so
%{_libdir}/cmake/lld/

%files libs
%{_libdir}/liblld*.so.*

%files doc
%doc README.md CODE_OWNERS.TXT docs/README.txt docs/ReleaseNotes.rst

%changelog
* Wed Feb 1 2023 Funda Wang <fundawang@yeah.net> - 15.0.7-1
- New version 15.0.7

* Fri Jul 29 2022 happy_orange <songnannan@linux.alibaba.com> - 13.0.1-1
- Init pcakage from upstream
